@@ -215,6 +215,9 @@ class Kivy4(MDApp):
 
                 return default == 'Dark'
 
+        except AttributeError:
+            return False
+
     def setDarkMode(self, value=None, filename='dark mode.txt'):
         if value is None:
             value = darkdetect.theme()
@@ -244,6 +247,9 @@ class Kivy4(MDApp):
 
                 return default
 
+        except AttributeError:
+            return False
+
     def setDarkModeIcon(self, value):
         if value == 'Dark':
             self.dark_mode_icon = self.moon_icon
@@ -279,7 +285,6 @@ Screen:
             id: screen_manager
 '''
 
-
     @staticmethod
     def custom_classes():
         return '''
